Skip to contents

The csv or the text file needs to have a header and be separated using comma. Under the first column in the text file, one needs to specify the site id and in the second column there has to be the name of the PFT.

Usage

loadPath.sitePFT(Path)

Arguments

Path

Character of file name with extension.

Value

a dataframe of two columns of site and pft