This will try and find the PEcAn settings file in the following order:
--settings <file>passed as command line argument using--settingsinputfilepassed as argument to functionPECAN_SETTINGSenvironment variablePECAN_SETTINGSpointing to a specific file./pecan.xmlpecan.xmlin the current folder
Details
Once the function finds a valid file, it will not look further.
Thus, if inputfile is supplied, PECAN_SETTINGS will be
ignored.
Even if a file argument is passed, it will be ignored if a file
is passed through a higher priority method.
Examples
test.settings.file <- system.file("test.xml", package = "PEcAn.settings")
settings <- read.settings(test.settings.file)